@@ -30,7 +30,7 @@ crsEst <- function(xz,
                    lambda=NULL,
                    complexity=c("degree-knots","degree","knots"),
                    knots=c("quantiles","uniform","auto"),
-                   basis=c("additive","tensor","glp","auto"),
+                   basis=c("auto","additive","tensor","glp"),
                    deriv=0,
                    data.return=FALSE,
                    prune=FALSE,
@@ -319,7 +319,7 @@ crs.default <- function(xz,
                         lambda=NULL,
                         complexity=c("degree-knots","degree","knots"),
                         knots=c("quantiles","uniform","auto"),
-                        basis=c("additive","tensor","glp","auto"),
+                        basis=c("auto","additive","tensor","glp"),
                         deriv=0,
                         data.return=FALSE,
                         prune=FALSE,
