@@ -1,16 +1,22 @@
 /*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.6.2        */
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
 /*                                                                                     */
-/*  Copyright (C) 2001-2012  Mark Abramson        - the Boeing Company, Seattle        */
-/*                           Charles Audet        - Ecole Polytechnique, Montreal      */
-/*                           Gilles Couture       - Ecole Polytechnique, Montreal      */
-/*                           John Dennis          - Rice University, Houston           */
-/*                           Sebastien Le Digabel - Ecole Polytechnique, Montreal      */
-/*                           Christophe Tribes    - Ecole Polytechnique, Montreal      */
 /*                                                                                     */
-/*  funded in part by AFOSR and Exxon Mobil                                            */
+/*  NOMAD - version 3.8.0 has been created by                                          */
+/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
+/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
+/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
+/*                                                                                     */
+/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
+/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
+/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
+/*                                                                                     */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
+/*                                                                                     */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
+/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
+/*  and were funded by AFOSR and Exxon Mobil.                                          */
 /*                                                                                     */
-/*  Author: Sebastien Le Digabel                                                       */
 /*                                                                                     */
 /*  Contact information:                                                               */
 /*    Ecole Polytechnique de Montreal - GERAD                                          */
@@ -34,14 +40,13 @@
 /*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
 /*-------------------------------------------------------------------------------------*/
 /**
-  \file   Direction.cpp
-  \brief  Polling direction (implementation)
-  \author Sebastien Le Digabel
-  \date   2010-04-05
-  \see    Direction.hpp
-*/
+ \file   Direction.cpp
+ \brief  Polling direction (implementation)
+ \author Sebastien Le Digabel
+ \date   2010-04-05
+ \see    Direction.hpp
+ */
 #include "Direction.hpp"
-using namespace std; // zhenghua
 
 /*-----------------------------------*/
 /*   static members initialization   */
@@ -55,34 +60,34 @@ int NOMAD::Direction::_max_cardinality = 0;
 /*                       constructor 1                     */
 /*---------------------------------------------------------*/
 NOMAD::Direction::Direction ( void )
-  : NOMAD::Point  (                            ) ,
-    _type         ( NOMAD::UNDEFINED_DIRECTION ) ,
-_index        ( -1                         ),
+: NOMAD::Point   (                            ) ,
+_type            ( NOMAD::UNDEFINED_DIRECTION ) ,
+_index           ( -1                         ),
 _dir_group_index (-1)
 {
 #ifdef MEMORY_DEBUG
-  ++NOMAD::Direction::_cardinality;
-  if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
-    ++NOMAD::Direction::_max_cardinality;
+    ++NOMAD::Direction::_cardinality;
+    if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
+        ++NOMAD::Direction::_max_cardinality;
 #endif
 }
 
 /*---------------------------------------------------------*/
 /*                       constructor 2                     */
 /*---------------------------------------------------------*/
-NOMAD::Direction::Direction ( int                     n    ,
-			      const NOMAD::Double   & v    ,
-			      NOMAD::direction_type   type ,		 
-					int dir_group_index		 )
-  : NOMAD::Point  ( n , v ) ,
-    _type         ( type  ) ,
-    _index        ( -1   ) ,
-    _dir_group_index (dir_group_index)
+NOMAD::Direction::Direction ( int                    n    ,
+                             const NOMAD::Double   & v    ,
+                             NOMAD::direction_type   type ,
+                             int dir_group_index          )
+: NOMAD::Point  ( n , v ) ,
+_type         ( type  ) ,
+_index        ( -1   ) ,
+_dir_group_index (dir_group_index)
 {
 #ifdef MEMORY_DEBUG
-  ++NOMAD::Direction::_cardinality;
-  if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
-    ++NOMAD::Direction::_max_cardinality;
+    ++NOMAD::Direction::_cardinality;
+    if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
+        ++NOMAD::Direction::_max_cardinality;
 #endif
 }
 
@@ -90,34 +95,34 @@ NOMAD::Direction::Direction ( int                     n    ,
 /*                       constructor 2b                    */
 /*---------------------------------------------------------*/
 NOMAD::Direction::Direction ( int                     n    ,
-							 const NOMAD::Double   & v    ,
-							 NOMAD::direction_type   type   )
+                             const NOMAD::Double   & v    ,
+                             NOMAD::direction_type   type   )
 : NOMAD::Point  ( n , v ) ,
 _type         ( type  ) ,
 _index        ( -1    ),
 _dir_group_index (-1)
 {
 #ifdef MEMORY_DEBUG
-  ++NOMAD::Direction::_cardinality;
-  if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
-    ++NOMAD::Direction::_max_cardinality;
+    ++NOMAD::Direction::_cardinality;
+    if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
+        ++NOMAD::Direction::_max_cardinality;
 #endif
 }
 
 /*---------------------------------------------------------*/
 /*                       constructor 3                     */
 /*---------------------------------------------------------*/
-NOMAD::Direction::Direction ( const NOMAD::Point    & x    , 
-			      NOMAD::direction_type   type   )
-  : NOMAD::Point  ( x    ) ,
-    _type         ( type ) ,
+NOMAD::Direction::Direction ( const NOMAD::Point    & x    ,
+                             NOMAD::direction_type   type   )
+: NOMAD::Point  ( x    ) ,
+_type         ( type ) ,
 _index        ( -1   ),
 _dir_group_index (-1)
 {
 #ifdef MEMORY_DEBUG
-  ++NOMAD::Direction::_cardinality;
-  if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
-    ++NOMAD::Direction::_max_cardinality;
+    ++NOMAD::Direction::_cardinality;
+    if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
+        ++NOMAD::Direction::_max_cardinality;
 #endif
 }
 
@@ -125,15 +130,15 @@ _dir_group_index (-1)
 /*                      copy constructor                   */
 /*---------------------------------------------------------*/
 NOMAD::Direction::Direction ( const Direction & d )
-  : NOMAD::Point  ( d        ) ,
-    _type         ( d._type  ) ,
-    _index        ( d._index ),
+: NOMAD::Point  ( d        ) ,
+_type         ( d._type  ) ,
+_index        ( d._index ),
 _dir_group_index (d._dir_group_index)
 {
 #ifdef MEMORY_DEBUG
-  ++NOMAD::Direction::_cardinality;
-  if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
-    ++NOMAD::Direction::_max_cardinality;
+    ++NOMAD::Direction::_cardinality;
+    if ( NOMAD::Direction::_cardinality > NOMAD::Direction::_max_cardinality )
+        ++NOMAD::Direction::_max_cardinality;
 #endif
 }
 
@@ -143,7 +148,7 @@ _dir_group_index (d._dir_group_index)
 NOMAD::Direction::~Direction ( void )
 {
 #ifdef MEMORY_DEBUG
-  --NOMAD::Direction::_cardinality;
+    --NOMAD::Direction::_cardinality;
 #endif
 }
 
@@ -152,15 +157,15 @@ NOMAD::Direction::~Direction ( void )
 /*---------------------------------------------------------*/
 NOMAD::Direction & NOMAD::Direction::operator = ( const NOMAD::Direction & d )
 {
-  if ( this == &d )
+    if ( this == &d )
+        return *this;
+    
+    NOMAD::Point::operator = ( d );
+    
+    _type  = d._type;
+    _index = d._index;
+    
     return *this;
-
-  NOMAD::Point::operator = ( d );
-  
-  _type  = d._type;
-  _index = d._index;
-
-  return *this;
 }
 
 /*---------------------------------------------------------*/
@@ -168,9 +173,9 @@ NOMAD::Direction & NOMAD::Direction::operator = ( const NOMAD::Direction & d )
 /*---------------------------------------------------------*/
 void NOMAD::Direction::clear ( void )
 {
-  NOMAD::Point::clear();
-  _type  = NOMAD::UNDEFINED_DIRECTION;
-  _index = -1;
+    NOMAD::Point::clear();
+    _type  = NOMAD::UNDEFINED_DIRECTION;
+    _index = -1;
 }
 
 /*-----------------------------------------------------------*/
@@ -178,22 +183,24 @@ void NOMAD::Direction::clear ( void )
 /*-----------------------------------------------------------*/
 const NOMAD::Direction NOMAD::Direction::operator - ( void ) const
 {
-  return NOMAD::Direction ( this->NOMAD::Point::operator-() , _type );
+    return NOMAD::Direction ( this->NOMAD::Point::operator-() , _type );
 }
 
+
 /*---------------------------------------------------------*/
 /*                          display                        */
 /*---------------------------------------------------------*/
 void NOMAD::Direction::display ( const NOMAD::Display & out ,
-				 const std::string    & sep ,
-				 int                    w   ,
-				 int                    lim   ) const
+                                const std::string    & sep ,
+                                int                    w   ,
+                                int                    lim   ) const
 {
-  if ( is_defined() ) {
-    out << "( ";
-    NOMAD::Point::display ( out , sep , w , lim );
-    out << " ) " << _type;
-  }
-  else
-    out << "undefined";
+    if ( is_defined() )
+    {
+        out << "( ";
+        NOMAD::Point::display ( out , sep , w , lim );
+        out << " ) " << _type;
+    }
+    else
+        out << "undefined";
 }
