@@ -1153,8 +1153,8 @@ double SGTELIB::Surrogate_Parameters::get_x_penalty ( void ){
     }
   }
 
-  if ( isinf(pen) ) pen=+INF;
-  if ( isnan(pen) ) pen=+INF;
+  if ( crs_isinf(pen) ) pen=+INF;
+  if ( crs_isnan(pen) ) pen=+INF;
   return pen;
 }
 
